@@ -1,24 +1,9 @@
 <?php
-/* vim: set expandtab tabstop=4 shiftwidth=4: */
-// +----------------------------------------------------------------------+
-// | PHP version 4                                                        |
-// +----------------------------------------------------------------------+
-// | Copyright (c) 1997-2004 The PHP Group                                |
-// +----------------------------------------------------------------------+
-// | This source file is subject to version 2.0 of the PHP license,       |
-// | that is bundled with this package in the file LICENSE, and is        |
-// | available through the world-wide-web at                              |
-// | http://www.php.net/license/2_02.txt.                                 |
-// | If you did not receive a copy of the PHP license and are unable to   |
-// | obtain it through the world-wide-web, please send a note to          |
-// | license@php.net so we can mail you a copy immediately.               |
-// +----------------------------------------------------------------------+
-// | Authors: Alexander Wirtz <alex@pc4p.net>                             |
-// +----------------------------------------------------------------------+
-//
-// $Id: weather.com-extensive.php,v 1.11 2004/07/10 12:37:14 eru Exp $
+/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4 foldmethod=marker: */
 
-/*
+/**
+ * Elaborate example for the GlobalWeather-service
+ *
  * Well, this is a more elaborate example how to create a neat little page
  * with fetching data from weather.com and putting it into a design.
  * I'm not too proud of my design-skills, most of the stuff here is taken
@@ -34,7 +19,47 @@
  * The design should adhere to the conventions defined by the weather.com
  * SDK-guide, though I won't give any legal certainty for this (of course).
  * Have fun!
-*/
+ * 
+ * PHP versions 4 and 5
+ *
+ * <LICENSE>
+ * Copyright (c) 2005-2007, Alexander Wirtz
+ * All rights reserved.
+ * 
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * o Redistributions of source code must retain the above copyright notice,
+ *   this list of conditions and the following disclaimer.
+ * o Redistributions in binary form must reproduce the above copyright notice,
+ *   this list of conditions and the following disclaimer in the documentation
+ *   and/or other materials provided with the distribution.
+ * o Neither the name of the software nor the names of its contributors
+ *   may be used to endorse or promote products derived from this software
+ *   without specific prior written permission.
+ * 
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+ * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
+ * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
+ * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
+ * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
+ * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
+ * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+ * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
+ * POSSIBILITY OF SUCH DAMAGE.
+ * </LICENSE>
+ * 
+ * @category    Web Services
+ * @package     Services_Weather
+ * @author      Alexander Wirtz <alex@pc4p.net>
+ * @copyright   2005-2007 Alexander Wirtz
+ * @license     http://www.opensource.org/licenses/bsd-license.php  BSD License
+ * @version     CVS: $Id: weather.com-extensive.php,v 1.16 2007/04/16 10:36:05 eru Exp $
+ * @link        http://pear.php.net/package/Services_Weather
+ * @filesource
+ */
 
 //-------------------------------------------------------------------------
 // This is the area, where you can customize the script
@@ -124,6 +149,11 @@ $fup  = strtotime($forecast["update"]) + $location["timezone"] * 3600;
 // This triggers if the day-forecast for the current day will get shown.
 $afternoon = ($location["time"] > "13:59" || date("Ymd", $fup) < date("Ymd")) ? true : false;
 
+// The usual notation for condition icons is numeric. Check for numeric icon or "na" and set to "na" if that's not the case
+if (!(ctype_digit($weather["conditionIcon"]) || $weather["conditionIcon"] == "na")) {
+    $weather["conditionIcon"] = "na";
+}
+
 // Now we output all the data, please don't expect extensive comments here, this is basic
 // HTML/CSS stuff. Also this isn't a very fancy design, it's just to show you, what
 // the script is able to do (and more ;-))...
@@ -253,6 +283,14 @@ for ($day = 0; $day < $forecastDays; $day++) {
     }
     // Afternoon is only important for today
     $afternoon = ($day == 0) ? $afternoon : false;
+
+    // The usual notation for condition icons is numeric. Check for numeric icon or "na" and set to "na" if that's not the case
+    if (!(ctype_digit($forecast["days"][$day]["day"]["conditionIcon"]) || $forecast["days"][$day]["day"]["conditionIcon"] == "na")) {
+        $forecast["days"][$day]["day"]["conditionIcon"] = "na";
+    }
+    if (!(ctype_digit($forecast["days"][$day]["night"]["conditionIcon"]) || $forecast["days"][$day]["night"]["conditionIcon"] == "na")) {
+        $forecast["days"][$day]["night"]["conditionIcon"] = "na";
+    }
 ?>
             <td style="width: <?=(90 / $forecastDays)?>%">
                 <table style="width: 100%"<?=($day % 2) ? ' class="bggrey"' : ""?>>
@@ -281,8 +319,8 @@ for ($day = 0; $day < $forecastDays; $day++) {
                         <td align="center" style="height: 45px"><?=$forecast["days"][$day]["night"]["precipitation"]?>%</td>
                     </tr>
                     <tr>
-                        <td align="center" style="height: 45px"><?=$afternoon ? "&nbsp;" : round($forecast["days"][$day]["day"]["wind"], 0).$units["wind"]." from&nbsp;".$forecast["days"][0]["day"]["windDirection"]?></td>
-                        <td align="center" style="height: 45px"><?=round($forecast["days"][$day]["night"]["wind"], 0).$units["wind"]?> from&nbsp;<?=$forecast["days"][0]["day"]["windDirection"]?></td>
+                        <td align="center" style="height: 45px"><?=$afternoon ? "&nbsp;" : round($forecast["days"][$day]["day"]["wind"], 0).$units["wind"]." from&nbsp;".$forecast["days"][$day]["day"]["windDirection"]?></td>
+                        <td align="center" style="height: 45px"><?=round($forecast["days"][$day]["night"]["wind"], 0).$units["wind"]?> from&nbsp;<?=$forecast["days"][$day]["night"]["windDirection"]?></td>
                     </tr>
                     <tr>
                         <td align="center" style="height: 15px"><?=$afternoon ? "" : $forecast["days"][$day]["day"]["humidity"]."%"?></td>
